@@ -344,7 +344,7 @@ double  dot(DETERMINANTE &a , DETERMINANTE &b);
 
 #define NONCREARE 0
 #define CREA      1
-#include<Sparsa.h>
+#include<Sparsa/Sparsa.h>
 
 class Risolutore {
 public:
@@ -828,4 +828,4 @@ double preJz(DETERMINANTE &a);
 
 #ifdef KDOC
 };
-#endif
\ No newline at end of file
+#endif
